aboutsummaryrefslogtreecommitdiffstats
path: root/prg2lout.c
diff options
context:
space:
mode:
authorJeffrey H. Kingston <jeff@it.usyd.edu.au>2010-09-14 19:38:17 +0000
committerJeffrey H. Kingston <jeff@it.usyd.edu.au>2010-09-14 19:38:17 +0000
commit73d840b9f14b65166b92e6b43f930fd0ef7b8267 (patch)
treef4eb37a19d1b8d6e9c038b5f3e4c24fc8083bad7 /prg2lout.c
parentd4b68bb27f42afb8338f35f9fda0c467ec5d8787 (diff)
downloadlout-73d840b9f14b65166b92e6b43f930fd0ef7b8267.tar.gz
Lout 3.19.
git-svn-id: http://svn.savannah.nongnu.org/svn/lout/trunk@7 9365b830-b601-4143-9ba8-b4a8e2c3339c
Diffstat (limited to 'prg2lout.c')
-rw-r--r--prg2lout.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/prg2lout.c b/prg2lout.c
index 4df2187..c8ba048 100644
--- a/prg2lout.c
+++ b/prg2lout.c
@@ -1,6 +1,6 @@
/*****************************************************************************/
/* */
/* PROG2LOUT: A PROGRAM TO CONVERT PROGRAM SOURCES INTO LOUT (VERSION 1.0) */
/* COPYRIGHT (C) 2000 Jeffrey H. Kingston */
/* */
/* Jeffrey H. Kingston (jeff@cs.su.oz.au) */
@@ -483,7 +483,7 @@ LANGUAGE *languages[] = {
#define DEBUG_EMIT 0
#define DEBUG_MAIN 0
-#define PROG2LOUT_VERSION "prg2lout Version 1.0 (February 2000)"
+#define PRG2LOUT_VERSION "prg2lout Version 1.0 (February 2000)"
#define BOOLEAN unsigned
#define FALSE 0
#define TRUE 1
@@ -1604,7 +1604,7 @@ int main(int argc, char *argv[])
{ fprintf(err_fp, "%s: -V illegal with -r option\n", ErrorHeader());
exit(1);
}
- fprintf(err_fp, "%s\n", PROG2LOUT_VERSION);
+ fprintf(err_fp, "%s\n", PRG2LOUT_VERSION);
exit(0);
break;
@@ -1,6 +1,6 @@
/*****************************************************************************/
/* */
-/* PROG2LOUT: A PROGRAM TO CONVERT PROGRAM SOURCES INTO LOUT (VERSION 1.0) */
+/* PRG2LOUT: A PROGRAM TO CONVERT PROGRAM SOURCES INTO LOUT (VERSION 1.0) */
/* COPYRIGHT (C) 2000 Jeffrey H. Kingston */
/* */